getRestDisplacementThreshold method
get the threshold of displacement from rest below which the spring should be considered at rest @return displacement to consider resting below
Implementation
double getRestDisplacementThreshold() {
return _mDisplacementFromRestThreshold;
}